@@ -90,7 +90,7 @@ ma.ses = function(target, dataset, ina, statistic = FALSE, max_k = 3 , threshold
   stat_hash = NULL;
   pvalue_hash = NULL;
   
-  if(hash == TRUE)
+  if( hash )
   {
     if(requireNamespace("hash"))
     {
@@ -101,9 +101,7 @@ ma.ses = function(target, dataset, ina, statistic = FALSE, max_k = 3 , threshold
       }else if(class(hashObject) == "list"){
         stat_hash = hashObject$stat_hash;
         pvalue_hash = hashObject$pvalue_hash;
-      }else{
-        stop('hashObject must be a list of two hash objects (stat_hash, pvalue_hash)')
-      }
+      }else  stop('hashObject must be a list of two hash objects (stat_hash, pvalue_hash)')
     }else{
       cat('The hash version of ma.ses requires the hash package');
       return(NULL);
@@ -118,33 +116,7 @@ ma.ses = function(target, dataset, ina, statistic = FALSE, max_k = 3 , threshold
   
 
   ## hey user, make sure everything is OK
-  
 
-  if(!is.null(dataset))
-  {
-    if( sum( class(target) == "matrix") == 1 )
-    {
-      if( sum( class(target) == "Surv") == 1 )
-      {
-        stop('Invalid dataset class. For survival analysis provide a dataframe-class dataset');
-      }
-    }
-    
-    #check if dataset is an ExpressionSet object of Biobase package
-    #if(class(dataset) == "ExpressionSet")
-    #{
-      #get the elements (numeric matrix) of the current ExpressionSet object.
-      #dataset = Biobase::exprs(dataset);
-      #dataset = t(dataset);#take the features as columns and the samples as rows
-#     }else if(is.data.frame(dataset)){
-#       if(class(target) != "Surv")
-#       {
-#         dataset = as.matrix(dataset);
-#       }
-    #}else if((class(dataset) != "matrix") & (is.data.frame(dataset) == FALSE) ){
-    #  stop('Invalid dataset class. It must be either a matrix, a dataframe or an ExpressionSet');
-    #}
-  }
     if(is.null(dataset) || is.null(target)) #|| (dim(as.matrix(target))[2] != 1 & class(target) != "Surv" ))
     {
       stop('invalid dataset or target (class feature) arguments.');
@@ -153,35 +125,27 @@ ma.ses = function(target, dataset, ina, statistic = FALSE, max_k = 3 , threshold
     }
   
     #check for NA values in the dataset and replace them with the variable median or the mode
-  if(any(is.na(dataset)) == TRUE)
-  {
-
-  
+  if( any(is.na(dataset)) ) {
     #dataset = as.matrix(dataset);
     warning("The dataset contains missing values (NA) and they were replaced automatically by the variable (column) median (for numeric) or by the most frequent level (mode) if the variable is factor")
-    
     if (class(dataset) == "matrix")  {
-    
-       dataset = apply(dataset, 2, function(x){ x[which(is.na(x))] = median(x, na.rm = TRUE) ; return(x)}) 
-              
+      dataset <- apply( dataset, 2, function(x){ x[which(is.na(x))] = median(x, na.rm = TRUE) ; return(x) } ) 
     }else{
-	
-    poia <- which( is.na(dataset), arr.ind = TRUE )[2]
- 	for( i in poia )
-      {
-          xi = dataset[, i]
-          if(class(xi) == "numeric")
-          {                    
-            xi[ which( is.na(xi) ) ] = median(xi, na.rm = TRUE) 
-          } else if ( class(xi) == "factor" ) {
-            xi[ which( is.na(xi) ) ] = levels(xi)[ which.max( as.vector( table(xi) ) )]
-          }
-          dataset[, i] = xi
+      poia <- which( is.na(dataset), arr.ind = TRUE )[2]
+      for( i in poia )  {
+        xi <- dataset[, i]
+        if(class(xi) == "numeric")
+        {                    
+          xi[ which( is.na(xi) ) ] <- median(xi, na.rm = TRUE) 
+        } else if ( is.factor( xi ) ) {
+          xi[ which( is.na(xi) ) ] <- levels(xi)[ which.max( as.vector( table(xi) ) )]
         }
+        dataset[, i] <- xi
+      }
     }
-    
   }
   
+  
   ##################################
   # target checking and initialize #
   ##################################
@@ -210,122 +174,11 @@ ma.ses = function(target, dataset, ina, statistic = FALSE, max_k = 3 , threshold
   }
   
 
-  if( sum( class(target) == "matrix") == 1 )
-  {
-    if(ncol(target) >= 2 & class(target) != "Surv")
-    {
-      if( (is.null(test) || test == "auto") & (is.null(user_test)) )
-      {
-
-      if ( min(target) > 0 & sum( rowSums(target) - 1 ) == 0 ) ## are they compositional data?
-      { 
-        target = log( target[, -1]/target[, 1] ) 
-      }
-        test = "testIndMVreg"
-        warning("Multivariate target (ncol(target) >= 2) requires a multivariate test of conditional independence. The testIndMVreg was used. For a user-defined multivariate test, please provide one in the user_test argument.");
-      }
-    }
-    
-  }
-  
   ################################
   # test checking and initialize #
   ################################
   
-  if(typeof(user_test) == "closure")
-  {
-    test = user_test;
-  }else{
-    #auto detect independence test in case of not defined by the user and the test is null or auto
-    if(is.null(test) || test == "auto")
-    {
-      
-        if ( length( unique(target) ) == 2 ) {
-          target = as.factor(target)
-        }
-      if ( sum( class(target) == "matrix") == 1 ) {
-        test = "testIndMVreg"
-      }
-      
-      #if target is a factor then use the Logistic test
-      if("factor" %in% class(target))
-      {
-        test = "testIndLogistic";
-        if(is.ordered(target) == TRUE)
-        {
-          dataInfo$target_type = "ordinal";
-          cat('\nTarget variable type: Ordinal')
-        }else{
-          if( length(unique(target)) == 2 )
-          {
-            dataInfo$target_type = "binary"
-            cat('\nTarget variable type: Binomial')
-          }else{
-            dataInfo$target_type = "nominal"
-            cat('\nTarget variable type: Nominal')
-          }
-        }
-        
-      }else if(class(target) == "numeric" || class(target) == "integer"){
-        
-        if( sum( floor(target) - target ) == 0 & length(target) > 2 )
-        {
-          test = "testIndPois";
-        }else{
-          if(class(dataset) == "matrix")
-          {
-            test = "testIndFisher";
-          }
-          else if(class(dataset) == "data.frame")
-          {
-            if(any(sapply(dataset, is.factor)))
-            {
-              test = "testIndReg";
-            }else{
-              test = "testIndFisher";
-            }
-          }
-        }
-        
-      }else if(survival::is.Surv(target) == TRUE){
-        test = "censIndCR";
-      }else{
-        stop('Target must be a factor, vector, matrix with at least 2 columns column or a Surv object');
-      }
-    }
-    
-    if(test == "testIndLogistic")
-    {
-      if(is.ordered(target) == TRUE)
-      {
-        dataInfo$target_type = "ordinal";
-        cat('\nTarget variable type: Ordinal')
-        
-        if(requireNamespace("ordinal", quietly = TRUE, warn.conflicts = FALSE)==FALSE)
-        {
-          cat("The testIndLogistic test requires the ordinal package for the ordered logistic regression method. Please install it.");
-          return(NULL);
-        }
-        
-      }else{
-        if(length(unique(target)) == 2)
-        {
-          dataInfo$target_type = "binary"
-          cat('\nTarget variable type: Binomial')
-        }else{
-          dataInfo$target_type = "nominal"
-          cat('\nTarget variable type: Nominal')
-          
-          if(requireNamespace("nnet", quietly = TRUE, warn.conflicts = FALSE)==FALSE)
-          {
-            cat("The testIndLogistic test requires the nnet package for the multinomial logistic regression method. Please install it.");
-            return(NULL);
-          }
-        }
-      }
-    }
-  
-  }  
+ 
     #cat("\nConditional independence test used: ");cat(test);cat("\n");
     
     #available conditional independence tests
@@ -334,20 +187,18 @@ ma.ses = function(target, dataset, ina, statistic = FALSE, max_k = 3 , threshold
     ci_test = test
     #cat(test)
     
-    if(length(test) == 1) #avoid vectors, matrices etc
-    {
-      test = match.arg(test , av_tests ,TRUE);
+    if(length(test) == 1)  {#avoid vectors, matrices etc
+
+      test = match.arg(test, av_tests, TRUE);
       #convert to closure type
-      if(test == "testIndFisher")
+      if(test == "testIndFisher") 
       {
         #an einai posostiaio target
-        if ( min(target) > 0 & max(target) < 1 ) {
-          target = log( target/(1 - target) ) ## logistic normal 
-        }
+        if ( min(target) > 0  &  max(target) < 1 )   target = log( target/(1 - target) ) ## logistic normal 
         
         if(class(dataset) == "data.frame")
         {
-          if(any(sapply(dataset, is.factor))){
+          if ( length( which_isFactor(dataset) ) > 0 ) {
             warning("Dataset contains categorical variables (factors). A regression model is advised to be used instead.")
           } else dataset <- as.matrix(dataset)
         }
@@ -357,13 +208,11 @@ ma.ses = function(target, dataset, ina, statistic = FALSE, max_k = 3 , threshold
       else if(test == "testIndSpearman")
       {
         #an einai posostiaio target
-        if ( min(target) > 0 & max(target) < 1 ) {
-          target = log( target / (1 - target) ) ## logistic normal 
-        }
+        if ( min(target) > 0  &  max(target) < 1 )   target = log( target / (1 - target) ) ## logistic normal 
         
         if(class(dataset) == "data.frame")
         {
-          if(any(sapply(dataset, is.factor))){
+          if ( length( which_isFactor(dataset) ) > 0 ) {
             warning("Dataset contains categorical variables (factors). A regression model is advised to be used instead.")
           } else dataset <- as.matrix(dataset)
         }
@@ -371,112 +220,8 @@ ma.ses = function(target, dataset, ina, statistic = FALSE, max_k = 3 , threshold
         dataset = apply(dataset, 2, rank)  
         test = testIndSpearman;  ## Spearman is Pearson on the ranks of the data
       }
-      else if (test == "testIndReg") ## It uses the F test
-      {
-
-        #an einai posostiaio target
-        if ( min(target) > 0 & max(target) < 1 ) {
-          target = log(target/(1-target)) ## logistic normal 
-        }
-        
-        test = testIndReg;
-      }
-      else if(test == "testIndMVreg")
-      {
-      if ( min(target) > 0 & sum( rowSums(target) - 1 ) == 0 ) ## are they compositional data?
-        { 
-          target = log( target[, -1]/target[, 1] ) 
-        }
-        test = testIndMVreg;
-      }     
-      else if(test == "testIndBeta") ## beta regression for proportions
-      {
-        test = testIndBeta;
-        if(requireNamespace("betareg", quietly = TRUE, warn.conflicts = FALSE)==FALSE)
-        {
-          cat("The testIndBeta requires the betareg package. Please install it.");
-          return(NULL);
-        }
-      }
-      else if(test == "testIndRQ") ## beta regression for proportions
-      {
-
-        #an einai posostiaio target
-        if ( all( target>0 & target<1 ) ){
-          target = log( target/(1 - target) ) ## logistic normal 
-        }
-        
-        test = testIndRQ;
-        if(requireNamespace("quantreg", quietly = TRUE, warn.conflicts = FALSE)==FALSE)
-        {
-          cat("The testIndRQ requires the quantreg package. Please install it.");
-          return(NULL);
-        }
-      }
-      else if (test == "testIndIGreg") ## Poisson regression
-      {
-        test = testIndIGreg;
-      }
-      else if (test == "testIndPois") ## Poisson regression
-      {
-        test = testIndPois;
-      }
-      else if (test == "testIndSpeedglm") ## Poisson regression
-      {
-        test = testIndSpeedglm;
-      }
-      else if (test == "testIndNB") ## Negative binomial regression
-      {
-        test = testIndNB;
-      }
-      else if (test == "testIndZIP") ## Poisson regression
-      {
-        test = testIndZIP;
-      }
-      else if(test == "censIndCR")
-      {
-        test = censIndCR;
-        if(requireNamespace("survival", quietly = TRUE, warn.conflicts = FALSE)==FALSE)
-        {
-          cat("The censIndCR requires the survival package. Please install it.");
-          return(NULL);
-        }
-      }
-      else if(test == "censIndWR")
-      {
-
-        test = censIndWR;
-        if(requireNamespace("survival", quietly = TRUE, warn.conflicts = FALSE)==FALSE)
-        {
-          cat("The censIndWR requires the survival package. Please install it.");
-          return(NULL);
-        }
-      }
-      else if(test == "testIndClogit")
-      {
-        test = testIndClogit;
-        if(requireNamespace("survival", quietly = TRUE, warn.conflicts = FALSE)==FALSE)
-        {
-          cat("The testIndClogit requires the survival package. Please install it.");
-          return(NULL);
-        }
-      }
-      else if(test == "testIndBinom")
-      {
-        test = testIndBinom;
-      }
-      else if(test == "testIndLogistic")
-      {
-        test = testIndLogistic;
-      }
-      else if(test == "gSquare")
-      {
-        test = gSquare;
-      }
-      #more tests here
-    }else{
-      stop('invalid test option');
-    }
+	    
+    } else   stop('invalid test option');
   
   
   ###################################
@@ -488,42 +233,24 @@ ma.ses = function(target, dataset, ina, statistic = FALSE, max_k = 3 , threshold
   varsize = ncol(dataset);
   
   #option checking
-  if((typeof(max_k)!="double") || max_k < 1)
-  {
-    stop('invalid max_k option');
-  }
-  if(max_k > varsize)
-  {
-    max_k = varsize;
-  }
-  if((typeof(threshold)!="double") || exp(threshold) <= 0 || exp(threshold) > 1)
-  {
-    stop('invalid threshold option');
-  }
-  if(typeof(equal_case)!="double")
-  {
-    stop('invalid equal_case option');
-  }
+  if((typeof(max_k)!="double") || max_k < 1)  stop('invalid max_k option');
+  if(max_k > varsize)  max_k = varsize;
+  if((typeof(threshold)!="double") || exp(threshold) <= 0 || exp(threshold) > 1)  stop('invalid threshold option');
+  if(typeof(equal_case)!="double")  stop('invalid equal_case option');
   
   #######################################################################################
   
-  if(!is.null(user_test))
-  {
-    ci_test = "user_test";
-  }
+  if ( !is.null(user_test) )  ci_test = "user_test";
 
   ## end of checking
-
   D = max(ina)
   
   targ = list()
   data = list()
-  for (l in 1:D) {
-   
+  for (l in 1:D) {  
    targ[[ l ]] = target[ ina == l ]
    data[[ l ]] = dataset[ ina == l, ]
-  }
-    
+  }   
 
   #call the main SES function after the checks and the initializations
   results = Internalmases(targ, data, statistic, max_k, threshold, test, ini, equal_case, user_test, dataInfo, hash, varsize, stat_hash, pvalue_hash, targetID, robust = robust, ncores = ncores);
@@ -546,7 +273,6 @@ Internalmases = function(targ , data, statistic, max_k, threshold , test = NULL
   
   #######################################################################################
   
-
   ## if testIndFisher is selected and the user has put robust =TRUE, the robust is not taken into consideration. 
   #univariate feature selection test
   
@@ -560,7 +286,7 @@ Internalmases = function(targ , data, statistic, max_k, threshold , test = NULL
 	
     univariateModels = list()
     
-    if ( identical(test, testIndFisher) == TRUE & robust == FALSE )  ## Pearson's correlation 
+    if ( identical(test, testIndFisher)  &  !robust )  ## Pearson's correlation 
     {
 	
 	  for ( l in 1:D ) {  
@@ -568,13 +294,11 @@ Internalmases = function(targ , data, statistic, max_k, threshold , test = NULL
 	  target = targ[[ l ]]
 	  dataset = data[[ l ]]
       rows = length(target)
-	
       a = as.vector( cor(target, dataset) )
       dof = rows - 3; #degrees of freedom
       wa = abs( 0.5 * log( (1 + a) / (1 - a) ) * sqrt(dof) )
       
-      if ( targetID != - 1 )  wa[ targetID ] = 0
-	  
+      if ( targetID != - 1 )  wa[ targetID ] = 0  
        sta[l, ] = wa
        pval[l, ] = log(2) + pt(-wa, dof, log.p = TRUE)
 	 }  
@@ -584,105 +308,28 @@ Internalmases = function(targ , data, statistic, max_k, threshold , test = NULL
       univariateModels$stat_hash = stat_hash;
       univariateModels$pvalue_hash = pvalue_hash;
 	 
-    } else if ( identical(test, testIndSpearman) == TRUE ) {  ## Spearman's correlation
+    } else if ( identical(test, testIndSpearman) ) {  ## Spearman's correlation
 	
 	 for ( l in 1:D ) {  
     
 	  target = targ[[ l ]]
 	  dataset = data[[ l ]]
-      rows = length(target)
-	  
+      rows = length(target) 
       a = as.vector( cor(target, dataset) )
       dof = rows - 3; #degrees of freedom
       wa = abs( 0.5 * log( (1 + a) / (1 - a) ) * sqrt(dof) / 1.029563 )
       
       if ( targetID != - 1 )  wa[ targetID ] = 0
-      
 	  sta[l, ] = wa
       pval[l, ] = log(2) + pt(-wa, dof, lower.tail = FALSE, log.p = TRUE)
 	 }  
- 
       univariateModels$stat = - 2 * Rfast::colsums(pval);
       univariateModels$pvalue = pchisq(univariateModels$stat, 2 * D, lower.tail = FALSE, log.p = TRUE) ;
       univariateModels$flag = numeric(cols) + 1;
       univariateModels$stat_hash = stat_hash;
       univariateModels$pvalue_hash = pvalue_hash;    
 	 
-    } else if ( identical(test, testIndBeta) == TRUE ) {  ## Beta regression
-      
-      univariateModels = list();
-      fit1 = betareg::betareg(target ~ 1)
-      lik2 = numeric(cols)
-      dof = numeric(cols)
-      
-      if ( ncores <= 1 | is.null(ncores) ) {
-        
-       for ( l in 1:D ) {  
-    
-	  target = targ[[ l ]]
-	  dataset = data[[ l ]]
-
-        for ( i in 1:cols ) {
-          
-          if (i != targetID){
-            
-            fit2 = betareg::betareg(target ~ dataset[, i] )
-            lik2[i] = as.numeric( logLik(fit2) )
-            dof[i] = length( coef(fit2) ) - 2
-          } else {
-            lik2[i] = lik1
-          }   
-        }
-        
-        lik1 = as.numeric( logLik(fit1) )
-        sta[l, ] = as.vector( 2 * abs(lik1 - lik2) )
-        pval[l, ] = pchisq(stat[l, ], dof, lower.tail = FALSE, log.p = TRUE)
-
-       }
- 
-        univariateModels$stat = - 2 * Rfast::colsums(pval)
-        univariateModels$pvalue = pchisq(univariateModels$stat, 2 * D, lower.tail = FALSE, log.p = TRUE) ;
-        univariateModels$flag = numeric(cols) + 1;
-        univariateModels$stat_hash = stat_hash;
-        univariateModels$pvalue_hash = pvalue_hash;
-        
-      } else {
-        
-       for (l in 1:D) {
-
-        target = targ[[ l ]]
-	  dataset = data[[ l ]]
-
-        cl <- makePSOCKcluster(ncores)
-        registerDoParallel(cl)
-        mod <- foreach(i = 1:cols, .combine = rbind, .packages = "betareg") %dopar% {
-          ## arguments order for any CI test are fixed
-          if ( i != targetID ) {
-            fit2 = betareg(target ~ dataset[, i] )
-            lik2 = as.numeric( logLik(fit2) )
-            
-            return( c(lik2, length( coef(fit2) ) ) )
-          } else{
-            return( c(0, 0) )
-          }
-        }
-        stopCluster(cl)
-        
-        lik1 = as.numeric( logLik(fit1) )
-        dof = as.vector( mod[, 2] ) - 2 
-        stat[l, ] = as.vector( 2 * abs(lik1 - mod[, 1]) )
-        pval[l, ] = pchisq(stat[l, ], dof, lower.tail = FALSE, log.p = TRUE)
-
-       }
- 
-        univariateModels$stat = - 2 * Rfast::colsums(pval)
-        univariateModels$pvalue = pchisq(univariateModels$stat, 2 * D, lower.tail = FALSE, log.p = TRUE) ;
-        univariateModels$flag = numeric(cols) + 1
-        univariateModels$stat_hash = NULL
-        univariateModels$pvalue_hash = NULL   
-      }
-      
-    } else if ( identical(test, testIndReg) == TRUE & robust == TRUE ) {  ## M (Robust) linear regression
+    } else if ( identical(test, testIndReg)  & robust ) {  ## M (Robust) linear regression
       
       univariateModels = list();
       fit1 = MASS::rlm(target ~ 1)
@@ -711,7 +358,7 @@ Internalmases = function(targ , data, statistic, max_k, threshold , test = NULL
         
         lik1 = as.numeric( logLik(fit1) )
         sta[l, ] = as.vector( 2 * abs(lik1 - lik2) )
-        pval[l, ] = pchisq(stat[l, ], dof, lower.tail = FALSE, log.p = TRUE)
+        pval[l, ] = pchisq(sta[l, ], dof, lower.tail = FALSE, log.p = TRUE)
 
        } 
 
@@ -747,7 +394,7 @@ Internalmases = function(targ , data, statistic, max_k, threshold , test = NULL
         lik1 = as.numeric( logLik(fit1) )
         dof = as.vector( mod[, 2] ) - 1 
         sta[l, ] = as.vector( 2 * abs(lik1 - mod[, 1]) )
-        pval[l, ] = pchisq(stat[l, ], dof, lower.tail = FALSE, log.p = TRUE)
+        pval[l, ] = pchisq(sta[l, ], dof, lower.tail = FALSE, log.p = TRUE)
 		
        }
 	   
@@ -759,7 +406,7 @@ Internalmases = function(targ , data, statistic, max_k, threshold , test = NULL
       }   
       
       
-    } else if ( identical(test, testIndLogistic) == TRUE  &  is.ordered(target) == TRUE  ) {  ## 
+    } else if ( identical(test, testIndLogistic)  &  is.ordered(target) ) {  ## 
       
       lik2 = numeric(cols)
       dof = numeric(cols)
@@ -790,7 +437,7 @@ Internalmases = function(targ , data, statistic, max_k, threshold , test = NULL
         
         lik1 = as.numeric( logLik(fit1) )
         sta[l, ] = as.vector( 2 * abs(lik1 - lik2) )
-        pval[l, ] = pchisq(stat[l, ], dof, lower.tail = FALSE, log.p = TRUE)
+        pval[l, ] = pchisq(sta[l, ], dof, lower.tail = FALSE, log.p = TRUE)
        
        }
  	   
@@ -826,7 +473,7 @@ Internalmases = function(targ , data, statistic, max_k, threshold , test = NULL
         lik1 = as.numeric( logLik(fit1) )
         dof = as.vector( mod[, 2] ) - df1 
         sta[l, ] = as.vector( 2 * abs(lik1 - mod[, 1]) )
-        pval[l, ] = pchisq(stat[l, ], dof, lower.tail = FALSE, log.p = TRUE)
+        pval[l, ] = pchisq(sta[l, ], dof, lower.tail = FALSE, log.p = TRUE)
 		
 	   }
 	   
@@ -837,234 +484,6 @@ Internalmases = function(targ , data, statistic, max_k, threshold , test = NULL
         univariateModels$pvalue_hash = NULL   
       }
       
-    } else if ( identical(test, testIndLogistic) == TRUE  &  is.ordered(target) == FALSE  &  length( unique(target) ) > 2  ) {  ## 
-      
-      target = as.factor( as.numeric( as.vector(target) ) );
-      
-      lik2 = numeric(cols)
-      dof = numeric(cols)
-      fit1 = nnet::multinom(target ~ 1, trace = FALSE)
-      df1 = length( coef(fit1) )
-      
-   
-      if ( ncores <= 1 | is.null(ncores) ) {
-
-	   for ( l in 1:D )	{
-	   
-	   target = targ[[ l ]]
-       dataset = data[[ l ]]
-	 
-        for ( i in 1:cols ) {
-          
-          if (i != targetID){
-            
-            fit2 = nnet::multinom(target ~ dataset[, i], trace = FALSE )
-            lik2[i] = as.numeric( logLik(fit2) )
-            dof[i] = length( coef(fit2) ) - df1
-          } else {
-            lik2[i] = lik1
-          }   
-        }
-        
-        
-        lik1 = as.numeric( logLik(fit1) )
-        sta[l, ] = as.vector( 2 * abs(lik1 - lik2) )
-        pval[l, ] = pchisq(stat[l, ], dof, lower.tail = FALSE, log.p = TRUE)
-	  } 	
-        univariateModels$stat = - 2 * Rfast::colsums(pval)
-        univariateModels$pvalue = pchisq(univariateModels$stat, 2 * D, lower.tail = FALSE, log.p = TRUE) ;
-        univariateModels$flag = numeric(cols) + 1;
-        univariateModels$stat_hash = stat_hash;
-        univariateModels$pvalue_hash = pvalue_hash;
-        
-      } else {
-        
-	   for ( l in 1:D ) {	
-	   
-	   target = targ[[ l ]]
-       dataset = data[[ l ]]
-	   
-        cl <- makePSOCKcluster(ncores)
-        registerDoParallel(cl)
-        mod <- foreach(i = 1:cols, .combine = rbind, .packages = "nnet") %dopar% {
-          ## arguments order for any CI test are fixed
-          if ( i != targetID ) {
-            
-            
-            fit2 = nnet::multinom(target ~ dataset[, i])
-            lik2 = as.numeric( logLik(fit2 ) )
-            
-            return( c(lik2, length( coef(fit2) ) ) )
-          } else{
-            return( c(0, 0) )
-          }
-        }
-        stopCluster(cl)
-        
-        lik1 = as.numeric( logLik(fit1) )
-        dof = as.vector( mod[, 2] ) - df1 
-        sta[l, ] = as.vector( 2 * abs(lik1 - mod[, 1]) )
-        pval[l, ] = pchisq(stat[l, ], dof, lower.tail = FALSE, log.p = TRUE)
-		
-	   }
-	   
-        univariateModels$stat = - 2 * Rfast::colsums(pval)
-        univariateModels$pvalue = pchisq(univariateModels$stat, 2 * D, lower.tail = FALSE, log.p = TRUE) ;
-        univariateModels$flag = numeric(cols) + 1
-        univariateModels$stat_hash = NULL
-        univariateModels$pvalue_hash = NULL   
-      
-	  }
-      
-    } else if ( identical(test, testIndZIP) == TRUE ) {  ## Zero-inflated Poisson regression
-      
-      univariateModels = list();
-      fit1 = pscl::zeroinfl(target ~ 1 | 1)
-      lik2 = numeric(cols)
-      dof = numeric(cols)
-      
-      if ( ncores <= 1 | is.null(ncores) ) {
-       
-       for ( l in 1:D )	{
-	   
-	   target = targ[[ l ]]
-       dataset = data[[ l ]]
-	 
-        for ( i in 1:cols ) {
-          
-          if ( i != targetID ) {
-            fit2 = pscl::zeroinfl( target ~ dataset[, i] | 1 )
-            lik2[i] = as.numeric( logLik(fit2) )
-            dof[i] = length( coef(fit2) ) - 2
-          } else {
-            lik2[i] = lik1
-          }
-        }
-        
-        lik1 = as.numeric( logLik(fit1) )
-        sta[l, ] = as.vector( 2 * abs(lik1 - lik2) )
-        pval[l, ] = pchisq(stat[l, ], dof, lower.tail = FALSE, log.p = TRUE)
-		
-       }
-	   
-        univariateModels$stat = - 2 * Rfast::colsums(pval)
-        univariateModels$pvalue = pchisq(univariateModels$stat, 2 * D, lower.tail = FALSE, log.p = TRUE) ;
-        univariateModels$flag = numeric(cols) + 1;
-        univariateModels$stat_hash = stat_hash;
-        univariateModels$pvalue_hash = pvalue_hash;
-        
-      } else {
-	  
-	   for ( l in 1:D )	{
-	   
-	   target = targ[[ l ]]
-       dataset = data[[ l ]]
-	   
-        cl <- makePSOCKcluster(ncores)
-        registerDoParallel(cl)
-        mod <- foreach(i = 1:cols, .combine = rbind, .packages = "pscl") %dopar% {
-          
-          if ( i != targetID ) {
-            fit2 = pscl::zeroinfl( target ~ dataset[, i] | 1 )
-            lik2 = as.numeric( logLik(fit2) )
-            
-            return( c(lik2, length( coef(fit2) ) ) )
-          } else{
-            return( c(0, 0) )
-          }
-          
-        }
-        stopCluster(cl)
-        
-        lik1 = as.numeric( logLik(fit1) )
-        dof = as.vector( mod[, 2] ) - 2 
-		sta[l, ] = as.vector( 2 * abs(lik1 - mod[, 1]) )
-        pval[l, ] = pchisq(stat[l, ], dof, lower.tail = FALSE, log.p = TRUE)
-		
-       }
-	   
-        univariateModels$stat = - 2 * Rfast::colsums(pval)
-        univariateModels$pvalue = pchisq(univariateModels$stat, 2 * D, lower.tail = FALSE, log.p = TRUE) ;
-        univariateModels$flag = numeric(cols) + 1
-        univariateModels$stat_hash = NULL
-        univariateModels$pvalue_hash = NULL   
-      }
-      
-    } else if ( identical(test, testIndRQ) == TRUE ) {  ## Median (quantile) regression
-      
-      univariateModels = list();
-      fit1 = quantreg::rq(target ~ 1)
-      stat = pval = numeric(cols)
-      
-      if ( ncores <= 1 | is.null(ncores) ) {
-       
-       for ( l in 1:D )	{
-	   
-	   target = targ[[ l ]]
-       dataset = data[[ l ]]
-	   
-        for ( i in 1:cols ) {
-          
-          if (i != targetID) {
-            
-            fit2 = quantreg::rq(target ~ dataset[, i] )
-            ww = anova(fit1, fit2, test = "rank")
-            df1 = as.numeric( ww[[1]][1] )
-            df2 = as.numeric( ww[[1]][2] )
-            sta[l, i] = as.numeric( ww[[1]][3] )
-            pval[l, i] = pf(stat[l, i], df1, df2, lower.tail = FALSE, log.p = TRUE)
-          } else {
-            pval[l, i] = log(1);
-            stat[l, i] = 0;
-          }
-        }
-       
-	   } 
-		
-        univariateModels$stat = - 2 * Rfast::colsums(pval)
-        univariateModels$pvalue = pchisq(univariateModels$stat, 2 * D, lower.tail = FALSE, log.p = TRUE) ;
-        univariateModels$flag = numeric(cols) + 1;
-        univariateModels$stat_hash = stat_hash;
-        univariateModels$pvalue_hash = pvalue_hash;
-        
-      } else {
-	  
-	   for ( l in 1:D )	{
-	   
-	   target = targ[[ l ]]
-       dataset = data[[ l ]]
-	   
-        cl <- makePSOCKcluster(ncores)
-        registerDoParallel(cl)
-        mod <- foreach(i = 1:cols, .combine = rbind, .packages = "quantreg") %dopar% {
-          
-          if (i != targetID) {
-            fit2 = quantreg::rq(target ~ dataset[, i] )
-            ww = anova(fit1, fit2, test = "rank")
-            df1 = as.numeric( ww[[1]][1] )
-            df2 = as.numeric( ww[[1]][2] )
-            st = as.numeric( ww[[1]][3] )
-            pv = pf(stat, df1, df2, lower.tail = FALSE, log.p = TRUE)
-            
-            return( c(st, pv ) )
-          } else{
-            return( c(0, 0) )
-          }
-          
-        }
-        stopCluster(cl)
-       
-	    pval[l, ] = mod[, 2]
-	   
-       } 	   
-        
-        univariateModels$stat = - 2 * Rfast::colsums(pval)
-        univariateModels$pvalue = pchisq(univariateModels$stat, 2 * D, lower.tail = FALSE, log.p = TRUE) ;
-        univariateModels$flag = numeric(cols) + 1
-        univariateModels$stat_hash = NULL
-        univariateModels$pvalue_hash = NULL   
-      }
-	  
     } else {  
       univariateModels = univariateScore.ma(targ, data, test, statistic = FALSE, dataInfo = dataInfo, hash=hash, stat_hash=stat_hash, pvalue_hash=pvalue_hash, targetID=targetID, robust=robust, ncores=ncores);
     }
@@ -1073,14 +492,13 @@ Internalmases = function(targ , data, statistic, max_k, threshold , test = NULL
     univariateModels = ini
   } 
     
-  
   pvalues = univariateModels$pvalue;      
   stats = univariateModels$stat;
   flags = univariateModels$flag;
 #   stat_hash = univariateModels$stat_hash;
 #   pvalue_hash = univariateModels$pvalue_hash;
   #if we dont have any associations , return
-  if ( min(pvalues , na.rm=TRUE) > threshold ) 
+  if ( min(pvalues, na.rm=TRUE) > threshold ) 
   {
     cat('No associations!');
     
@@ -1335,10 +753,7 @@ IdentifyEquivalence.ma = function(equal_case, queues, target, dataset, test, thr
   for(cvar in varsToBeConsidered)
   {
     #if var is the last one added, no sense to perform the check
-    if (cvar == lastvar) #CHANGE
-    {
-      next;
-    }
+    if (cvar == lastvar)  next;
     
     #the maximum conditioning set
     selectedVarsIDs = which(selectedVars == 1);
@@ -1356,7 +771,7 @@ IdentifyEquivalence.ma = function(equal_case, queues, target, dataset, test, thr
       {
         subsetcsk = as.matrix(lastvar); #CHANGE
       }else{
-        subsetcsk = nchoosek(tempCS, klimit - 1)   
+        subsetcsk = as.matrix( nchoosek(tempCS, klimit - 1) )   
         numSubsets = dim(subsetcsk)[2]; 
         subsetcsk = rbind(subsetcsk, lastvar*rep(1,numSubsets));#CHANGE
       }
@@ -1395,8 +810,8 @@ IdentifyEquivalence.ma = function(equal_case, queues, target, dataset, test, thr
         }
       }
       
-      if(breakFlag == TRUE)
-      {
+      if( breakFlag )
+      { 
         break;
       }else
       {
@@ -1520,7 +935,7 @@ min_assoc.ma = function(target, dataset, test, max_k, cvar, statistic, selectedV
     {
       subsetcsk = as.matrix(lastvar); #CHANGE
     }else{
-      subsetcsk = nchoosek(tempCS, ck - 1)  
+      subsetcsk = as.matrix( nchoosek(tempCS, ck - 1) )
       numSubsets = dim(subsetcsk)[2]; #CHANGE
       subsetcsk = rbind(subsetcsk, lastvar*rep(1,numSubsets)); #CHANGE
     }
