@@ -37,24 +37,18 @@ testIndBeta = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NU
   #   [1] Ferrari S.L.P., Cribari-Neto F. (2004). Beta Regression for  
   #   Modelling Rates and Proportions. Journal of Applied Statistics, 
   #   31(7): 799--815.
- 
-
-
   
   #initialization
   
-  #cast factor into numeric vector
-  target = as.numeric(as.vector(target));
-  
   csIndex[which(is.na(csIndex))] = 0
   
-  if(hash == TRUE)
+  if( hash )
   {
     csIndex2 = csIndex[which(csIndex!=0)]
     csindex2 = sort(csIndex2)
     xcs = c(xIndex,csIndex2)
     key = paste(as.character(xcs) , collapse=" ");
-    if(is.null(stat_hash[[key]]) == FALSE)
+    if( !is.null(stat_hash[[key]]) )
     {
       stat = stat_hash[[key]];
       pvalue = pvalue_hash[[key]];
@@ -72,9 +66,9 @@ testIndBeta = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NU
   
   #if the xIndex is contained in csIndex, x does not bring any new
   #information with respect to cs
-  if(!is.na(match(xIndex,csIndex)))
+  if( !is.na(match(xIndex,csIndex)) )
   {
-    if(hash == TRUE)#update hash objects
+    if( hash )#update hash objects
     {
       stat_hash[[key]] <- 0;#.set(stat_hash , key , 0)
       pvalue_hash[[key]] <- log(1);#.set(pvalue_hash , key , 1)
@@ -98,16 +92,10 @@ testIndBeta = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NU
   x = dataset[ , xIndex];
   cs = dataset[ , csIndex];
   
-#   if(length(csIndex) > 1)
-#   {
-#     #remove same columns
-#     cs = unique(as.matrix(cs), MARGIN = 2);
-#   }
-  
   #if x or target is constant then there is no point to perform the test
-  if( var( as.numeric(x) ) == 0 || var(target) == 0)
+  if( vara( as.numeric(x) ) == 0 )
   {
-    if(hash == TRUE)#update hash objects
+    if( hash )#update hash objects
     {
       stat_hash[[key]] <- 0;#.set(stat_hash , key , 0)
       pvalue_hash[[key]] <- log(1);#.set(pvalue_hash , key , 1)
@@ -119,24 +107,17 @@ testIndBeta = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NU
   #remove NAs-zeros from cs
   #csIndex = csIndex[csIndex!=0]
   
-  #remove constant columns of cs
-  cs = as.matrix(cs)
-  cs = cs[,apply(cs, 2, var, na.rm=TRUE) != 0]
-  
-  if(length(cs) == 0 || is.na(cs) == TRUE)
-  {
-    cs = NULL;
-  }
+  if( length(cs) == 0 || is.na(cs) )  cs = NULL;
   
   #if x = any of the cs then pvalue = 1 and flag = 1.
   #That means that the x variable does not add more information to our model due to an exact copy of this in the cs, so it is independent from the target
   if(length(cs)!=0)
   {
-    if(is.null(dim(cs)[2]) == TRUE) #cs is a vector
+    if( is.null(dim(cs)[2]) ) #cs is a vector
     {
       if(any(x != cs) == FALSE)  #if(!any(x == cs) == FALSE)
       {
-        if(hash == TRUE)#update hash objects
+        if( hash )#update hash objects
         {
           stat_hash[[key]] <- 0;#.set(stat_hash , key , 0)
           pvalue_hash[[key]] <- log(1);#.set(pvalue_hash , key , 1)
@@ -149,7 +130,7 @@ testIndBeta = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NU
       {
         if(any(x != cs[,col]) == FALSE)  #if(!any(x == cs) == FALSE)
         {
-          if(hash == TRUE)#update hash objects
+          if( hash )#update hash objects
           {
             stat_hash[[key]] <- 0;#.set(stat_hash , key , 0)
             pvalue_hash[[key]] <- log(1);#.set(pvalue_hash , key , 1)
@@ -161,14 +142,6 @@ testIndBeta = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NU
     }
   }
    
-  #checking the length
-  if (length(x) == 0 || length(target) == 0)
-  {
-    message(paste("error in testIndBeta : empty variable x or target"))
-    results <- list(pvalue = pvalue, stat = stat, flag = flag, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
-    return(results);
-  }
-  n=length(target)  ## sample size
 
   #trycatch for dealing with errors
   res <- tryCatch(
@@ -187,24 +160,24 @@ testIndBeta = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NU
       return(results);
     }
      #Fitting beta regressions
-      fit1 = betareg::betareg(target ~ 1)
-      fit2 = betareg::betareg(target ~ x )
+      if ( is.null(wei) )  fit1 = Rfast::beta.mle(target)  else  fit1 <- betamle.wei(target, wei)
+      fit2 = beta.reg(target, x, wei = wei)
   }else{
       #Fitting beta regressions
 
-      fit1 = betareg::betareg( target ~., data = as.data.frame( dataset[, csIndex] ), weights = wei )
-      fit2 = betareg::betareg(target ~., data = as.data.frame( dataset[, c(csIndex, xIndex)] ), weights = wei )  ;
+      fit1 = beta.reg( target, dataset[, csIndex], wei = wei )
+      fit2 = beta.reg(target, dataset[, c(csIndex, xIndex)] , wei = wei )  ;
   }
-      lik1 = as.numeric( logLik(fit1) )
-      lik2 = as.numeric( logLik(fit2) )
+      lik1 = fit1$loglik
+      lik2 = fit2$loglik
       stat = 2 * abs(lik1 - lik2)
-      dof = length( coef(fit2) ) - length( coef(fit1) )
+      dof = length( fit2$be ) - length( fit1$be )
       pvalue = pchisq(stat, dof, lower.tail = FALSE, log.p = TRUE) 
   
   #calculate the p value and stat.
   flag = 1;
   #update hash objects
-  if(hash == TRUE)
+  if( hash )
   {
     stat_hash[[key]] <- stat;#.set(stat_hash , key , stat)
     pvalue_hash[[key]] <- pvalue;#.set(pvalue_hash , key , pvalue)
@@ -212,12 +185,19 @@ testIndBeta = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NU
   
   #last error check
   if(is.na(pvalue) || is.na(stat))
-  { 
+  {
+    pvalue = log(1);
+    stat = 0;
     flag = 0;
+  }else{
+    #update hash objects
+    if( hash )
+    {
+      stat_hash[[key]] <- stat;#.set(stat_hash , key , stat)
+      pvalue_hash[[key]] <- pvalue;#.set(pvalue_hash , key , pvalue)
+    }
   }
-  
   #testerrorcaseintrycatch(4);
-  
   results <- list(pvalue = pvalue, stat = stat, flag = flag, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
   return(results);
   
