@@ -41,8 +41,7 @@ testIndFisher = function(target, dataset, xIndex, csIndex, wei = NULL, statistic
     n = length( target )
     csIndex[which(is.na(csIndex))] = 0;
     
-    if ( hash )
-    {
+    if ( hash )  {
       csIndex2 = csIndex[which(csIndex!=0)]
       csindex2 = sort(csIndex2)
       xcs = c(xIndex,csIndex2)
@@ -82,11 +81,9 @@ testIndFisher = function(target, dataset, xIndex, csIndex, wei = NULL, statistic
     
     xIndex = unique(xIndex);
     csIndex = unique(csIndex);
-    
     #extract the data
     x = dataset[ , xIndex];
     cs = dataset[ , csIndex];
-       
     #if x = any of the cs then pvalue = 1 and flag = 1.
     #That means that the x variable does not add more information to our model due to an exact copy of this in the cs, so it is independent from the target
     if(length(cs)!=0)
@@ -135,7 +132,6 @@ testIndFisher = function(target, dataset, xIndex, csIndex, wei = NULL, statistic
     #remove constant columns of cs
     cs = as.matrix(cs)
     cs = cs[, apply(cs, 2, var, na.rm=TRUE) != 0]  
-    
     #trycatch for dealing with errors
     res <- tryCatch(
       {
@@ -173,16 +169,12 @@ testIndFisher = function(target, dataset, xIndex, csIndex, wei = NULL, statistic
           }
         }
         #lets calculate the p-value
-        
-        #comparing against the Student's t distribution
         z = 0.5*log( (1+stat)/(1-stat) );
         dof = n - ncol(as.matrix(cs)) - 3; #degrees of freedom
         stat = sqrt(dof) * abs(z);
-        
         pvalue = log(2) + pt(-stat, dof, log.p = TRUE) ;  # ?dt for documentation
         #or alternatively we can calculate the p-value by comparing against the normal distribution
         #pvalue = 2 * pnorm(-abs(w));  ### 
-        
         flag = 1;
         
         #last error check
@@ -232,8 +224,7 @@ testIndFisher = function(target, dataset, xIndex, csIndex, wei = NULL, statistic
     )  
   
 
-            ## meta-analytic approach
-
+    ## meta-analytic approach
 ##################################
   
   
@@ -380,10 +371,8 @@ aa[[ i ]] <- tryCatch(
       b1 = coef( MASS::rlm(targ ~ x, maxit = 2000 ) )[2]
       b2 = coef( MASS::rlm(x ~ targ, maxit = 2000 ) )[2]
       stat = sqrt( abs (b1 * b2) ) 
-    }else{
-      stat = cor(x, targ);
-    }
-
+    } else  stat = cor(x, targ);
+    
   } else{
      #perform the test with the cs
 
@@ -402,16 +391,12 @@ aa[[ i ]] <- tryCatch(
   }
 
   #lets calculate the p-value
-  
-  #comparing against the Student's t distribution
   z = 0.5 * log( (1 + stat) / (1 - stat) );
   dof = n - NCOL(cs) - 3; #degrees of freedom
   stat = sqrt(dof) * abs(z) ; ## standard errot for Spearman
-  
   pvalue = log(2) + pt(-stat, dof, log.p = TRUE) ;  # ?dt for documentation
   #or alternatively we can calculate the p-value by comparing against the normal distribution
   #pvalue = 2 * pnorm(-w);  ### 
-  
   flag = 1;
   
   #last error check
@@ -430,7 +415,6 @@ aa[[ i ]] <- tryCatch(
   }
   
   #testerrorcaseintrycatch(4);
-  
    list(pvalue = pvalue, z = z, nu = n, stat = stat, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
   
 },
@@ -461,9 +445,9 @@ finally={}
   
 }
 
- if  ( !statistic ) {
+  if  ( !statistic ) {
     
-	pva <- numeric(D) 
+	  pva <- numeric(D) 
     for ( j in 1:D )   pva[j] = -2 * aa[[ j ]]$pvalue
   
     stat = sum(pva)
@@ -471,19 +455,18 @@ finally={}
   
   } else {
     sta <- se <- numeric(D) 
-	cisa = ncol(cs)
+	  cisa = ncol(cs)
 	
     for ( j in 1:D )  {
-	  sta[j] = aa[[ j ]]$z
-	  se[j] = 1 / sqrt(aa[ j ]$nu -  cisa - 3 ) 
+	    sta[j] = aa[[ j ]]$z
+	    se[j] = 1 / sqrt(aa[ j ]$nu -  cisa - 3 ) 
     }
 	
-	sse <- sum(se)
-	stat <- (sta * se) / sqrt( sse )
-	pvalue <- log(2) + pnorm( -abs(stat), log.p = TRUE )
+  	sse <- sum(se)
+	  stat <- (sta * se) / sqrt( sse )
+	  pvalue <- log(2) + pnorm( -abs(stat), log.p = TRUE )
   }
   
-  
   if ( hash ) {
     
     stat_hash[[key]] <- stat
@@ -492,9 +475,7 @@ finally={}
   }
 
  res = list(pvalue = pvalue, stat = stat, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
-
 }
   
  return(res)
-  
 }
\ No newline at end of file
